#[non_exhaustive]pub enum DeriveError {
Mnemonic(Error),
InvalidWordCount(usize),
PrefixTooShort {
prefix: String,
min_len: usize,
},
UnknownPrefix(String),
AmbiguousPrefix {
prefix: String,
candidates: Vec<String>,
},
IndexOverflow,
InvalidHex(String),
}Expand description
Errors that can occur during wallet operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Mnemonic(Error)
Invalid mnemonic phrase.
InvalidWordCount(usize)
Invalid word count for mnemonic.
PrefixTooShort
Mnemonic prefix is too short for unambiguous expansion.
UnknownPrefix(String)
Mnemonic prefix does not match any word in the wordlist.
AmbiguousPrefix
Mnemonic prefix matches multiple words in the wordlist.
IndexOverflow
Index overflow in batch derivation.
InvalidHex(String)
Stored hex material is malformed.
Produced by the byte-level accessors on DerivedAccount /
DerivedAddress when decoding their hex fields. Derivers in this
workspace never produce malformed hex, so this error indicates
externally-constructed data.