pub enum Language {
English,
}Expand description
Language to be used for the mnemonic phrase.
The English language is always available, other languages are enabled using the compilation features.
Variants
English
The English language.
Implementations
Sourceimpl Language
impl Language
Sourcepub const ALL: &'static [Language]
pub const ALL: &'static [Language]
The list of supported languages. Language support is managed by compile features.
Sourcepub fn all() -> &'static [Language]
👎Deprecated since 2.1.0: use constant Language::ALL instead
pub fn all() -> &'static [Language]
use constant Language::ALL instead
The list of supported languages. Language support is managed by compile features.
Sourcepub fn words_by_prefix(self, prefix: &str) -> &[&'static str]
pub fn words_by_prefix(self, prefix: &str) -> &[&'static str]
Get words from the word list that start with the given prefix.