Multi-chain HD wallet derivation library.
Core Wallet type holds a BIP-39 mnemonic and derives seeds for
chain-specific derivers (kobe-evm, kobe-btc, kobe-svm, etc.).
let wallet = kobe_primitives::Wallet::from_mnemonic(
"abandon abandon abandon abandon abandon abandon abandon abandon abandon abandon abandon about",
None,
)?;Re-exports
pub use bip39::rand_core;
Modules
- bip32
- BIP-32 secp256k1 key derivation utilities.
- camouflage
- Mnemonic camouflage via entropy-layer XOR encryption.
- mnemonic
- BIP-39 mnemonic utilities.
- slip10
- SLIP-0010 Ed25519 key derivation.
- test_
vectors - Well-known BIP-39 / SLIP-10 test vectors, exposed for downstream test suites.
Structs
- Derived
Account - A derived HD account — unified across all chains.
- Wallet
- A unified HD wallet that can derive keys for multiple cryptocurrencies.
Enums
- Derive
Error - Errors produced by core wallet and key-derivation operations.
- Language
- Language to be used for the mnemonic phrase.
Traits
- Derive
- Unified derivation trait implemented by all chain derivers.
- Derive
Ext - Extension trait providing batch derivation for all
Deriveimplementors.
Functions
- derive_
range - Derive a range of accounts by repeatedly invoking a derivation closure.
Type Aliases
- Result
- Convenient Result alias.